@@ -1,9 +1,14 @@
-﻿define(['imageLoader', 'layoutManager', 'viewManager', 'navdrawer', 'libraryBrowser', 'apphost', 'paper-icon-button-light', 'material-icons'], function (imageLoader, layoutManager, viewManager, navdrawer, libraryBrowser, appHost) {
+﻿define(['imageLoader', 'layoutManager', 'viewManager', 'libraryBrowser', 'apphost', 'paper-icon-button-light', 'material-icons'], function (imageLoader, layoutManager, viewManager, libraryBrowser, appHost) {
 
-    var navDrawerElement = document.querySelector('.mainDrawer');
-    var navDrawerScrollContainer = navDrawerElement.querySelector('.scrollContainer');
+    var enableBottomTabs = AppInfo.isNativeApp;
+    var enableLibraryNavDrawer = !enableBottomTabs;
+
+    var navDrawerElement;
+    var navDrawerScrollContainer;
     var navDrawerInstance;
 
+    var mainDrawerButton;
+
     function renderHeader() {
 
         var html = '';
@@ -11,10 +16,10 @@
         html += '<div class="primaryIcons">';
         var backIcon = browserInfo.safari ? 'chevron_left' : '&#xE5C4;';
 
-        html += '<button type="button" is="paper-icon-button-light" class="headerButton headerButtonLeft headerBackButton hide autoSize"><i class="md-icon">' + backIcon + '</i></button>';
+        html += '<button type="button" is="paper-icon-button-light" class="headerButton headerButtonLeft headerBackButton hide"><i class="md-icon">' + backIcon + '</i></button>';
 
-        html += '<button type="button" is="paper-icon-button-light" class="headerButton mainDrawerButton barsMenuButton headerButtonLeft autoSize"><i class="md-icon">menu</i></button>';
-        html += '<button type="button" is="paper-icon-button-light" class="headerButton headerAppsButton barsMenuButton headerButtonLeft autoSize"><i class="md-icon">home</i></button>';
+        html += '<button type="button" is="paper-icon-button-light" class="headerButton mainDrawerButton barsMenuButton headerButtonLeft hide"><i class="md-icon">menu</i></button>';
+        html += '<button type="button" is="paper-icon-button-light" class="headerButton headerAppsButton barsMenuButton headerButtonLeft"><i class="md-icon">home</i></button>';
 
         html += '<div class="libraryMenuButtonText headerButton">' + Globalize.translate('ButtonHome') + '</div>';
 
@@ -23,9 +28,7 @@
         html += '<span class="headerSelectedPlayer"></span>';
         html += '<button is="paper-icon-button-light" class="btnCast headerButton headerButtonRight hide autoSize"><i class="md-icon">cast</i></button>';
 
-        if (AppInfo.enableSearchInTopMenu) {
-            html += '<button type="button" is="paper-icon-button-light" class="headerButton headerButtonRight headerSearchButton hide autoSize"><i class="md-icon">search</i></button>';
-        }
+        html += '<button type="button" is="paper-icon-button-light" class="headerButton headerButtonRight headerSearchButton hide autoSize"><i class="md-icon">search</i></button>';
 
         html += '<button is="paper-icon-button-light" class="headerButton headerButtonRight headerVoiceButton hide autoSize"><i class="md-icon">mic</i></button>';
 
@@ -57,12 +60,7 @@
 
     function onBackClick() {
 
-        if (Dashboard.exitOnBack()) {
-            Dashboard.exit();
-        }
-        else {
-            history.back();
-        }
+        Emby.Page.back();
     }
 
     function updateUserInHeader(user) {
@@ -184,7 +182,7 @@
 
     function bindMenuEvents() {
 
-        var mainDrawerButton = document.querySelector('.mainDrawerButton');
+        mainDrawerButton = document.querySelector('.mainDrawerButton');
 
         if (mainDrawerButton) {
             mainDrawerButton.addEventListener('click', toggleMainDrawer);
@@ -336,11 +334,13 @@
 
     function refreshDashboardInfoInDrawer(page, user) {
 
-        if (!navDrawerScrollContainer.querySelector('.adminDrawerLogo')) {
-            createDashboardMenu(page);
-        } else {
-            updateDashboardMenuSelectedItem();
-        }
+        loadNavDrawer().then(function () {
+            if (!navDrawerScrollContainer.querySelector('.adminDrawerLogo')) {
+                createDashboardMenu(page);
+            } else {
+                updateDashboardMenuSelectedItem();
+            }
+        });
     }
 
     function updateDashboardMenuSelectedItem() {
@@ -366,9 +366,7 @@
                 var secondaryTitle = (link.innerText || link.textContent).trim();
                 title += secondaryTitle;
 
-                var documentTitle = secondaryTitle;
-
-                Dashboard.setPageTitle(title, documentTitle);
+                LibraryMenu.setTitle(title);
 
             } else {
                 link.classList.remove('selectedSidebarLink');
@@ -689,7 +687,7 @@
                 var helpUrl = page.getAttribute('data-helpurl');
 
                 if (helpUrl) {
-                    html += '<a href="' + helpUrl + '" target="_blank" class="clearLink" style="margin-left:2em;" title="' + Globalize.translate('ButtonHelp') + '"><button is="emby-button" type="button" class="accent" style="margin:0;font-weight:normal;font-size:14px;padding:.25em;display:block;align-items:center;"><i class="md-icon">info</i><span>' + Globalize.translate('ButtonHelp') + '</span></button></a>';
+                    html += '<a href="' + helpUrl + '" target="_blank" class="clearLink" style="margin-left:2em;" title="' + Globalize.translate('ButtonHelp') + '"><button is="emby-button" type="button" class="button-accent-flat" style="margin:0;font-weight:normal;font-size:14px;padding:.25em;display:block;align-items:center;"><i class="md-icon">info</i><span>' + Globalize.translate('ButtonHelp') + '</span></button></a>';
                 }
             }
 
@@ -697,33 +695,10 @@
             if (libraryMenuButtonText) {
                 libraryMenuButtonText.innerHTML = html;
             }
+
+            document.title = title || 'Emby';
         },
 
-        setBackButtonVisible: function (visible) {
-
-            var backButton = document.querySelector('.headerBackButton');
-
-            if (backButton) {
-                if (visible) {
-                    backButton.classList.remove('hide');
-                } else {
-                    backButton.classList.add('hide');
-                }
-            }
-        },
-
-        setMenuButtonVisible: function (visible) {
-
-            var mainDrawerButton = document.querySelector('.mainDrawerButton');
-
-            if (mainDrawerButton) {
-                if (!visible && browserInfo.mobile) {
-                    mainDrawerButton.classList.remove('hide');
-                } else {
-                    mainDrawerButton.classList.remove('hide');
-                }
-            }
-        },
         setTransparentMenu: function (transparent) {
 
             var viewMenuBar = document.querySelector('.viewMenuBar');
@@ -866,9 +841,21 @@
         var isDashboardPage = page.classList.contains('type-interior');
 
         if (isDashboardPage) {
+            if (mainDrawerButton) {
+                mainDrawerButton.classList.remove('hide');
+            }
             refreshDashboardInfoInDrawer(page);
         } else {
-            if (navDrawerElement.classList.contains('adminDrawer')) {
+
+            if (mainDrawerButton) {
+                if (enableLibraryNavDrawer) {
+                    mainDrawerButton.classList.remove('hide');
+                } else {
+                    mainDrawerButton.classList.add('hide');
+                }
+            }
+
+            if ((navDrawerElement && navDrawerElement.classList.contains('adminDrawer')) || (!navDrawerElement && enableLibraryNavDrawer)) {
                 refreshLibraryDrawer();
             }
         }
@@ -908,15 +895,8 @@
     });
 
     function updateTitle(page) {
-        var title = page.getAttribute('data-title') || page.getAttribute('data-contextname');
 
-        if (!title) {
-            var titleKey = getParameterByName('titlekey');
-
-            if (titleKey) {
-                title = Globalize.translate(titleKey);
-            }
-        }
+        var title = page.getAttribute('data-title');
 
         if (title) {
             LibraryMenu.setTitle(title);
@@ -925,18 +905,10 @@
 
     function updateBackButton(page) {
 
-        var canGoBack = !page.classList.contains('homePage') && history.length > 0;
-
         var backButton = document.querySelector('.headerBackButton');
 
-        var showBackButton = AppInfo.enableBackButton;
-
-        if (!showBackButton) {
-            showBackButton = page.getAttribute('data-backbutton') == 'true';
-        }
-
         if (backButton) {
-            if (canGoBack && showBackButton) {
+            if (page.getAttribute('data-backbutton') == 'true' && Emby.Page.canGoBack()) {
                 backButton.classList.remove('hide');
             } else {
                 backButton.classList.add('hide');
@@ -946,10 +918,6 @@
 
     function initHeadRoom(elem) {
 
-        if (!AppInfo.enableHeadRoom) {
-            return;
-        }
-
         require(["headroom-window"], function (headroom) {
 
             headroom.add(elem);
@@ -979,24 +947,34 @@
             admin = true;
         }
 
-        if (admin) {
-            navDrawerElement.classList.add('adminDrawer');
-            navDrawerElement.classList.remove('darkDrawer');
-        } else {
-            navDrawerElement.classList.add('darkDrawer');
-            navDrawerElement.classList.remove('adminDrawer');
+        var enableNavDrawer = admin || enableLibraryNavDrawer;
+        if (enableNavDrawer) {
+            loadNavDrawer().then(function () {
+                if (admin) {
+                    navDrawerElement.classList.add('adminDrawer');
+                    navDrawerElement.classList.remove('darkDrawer');
+                } else {
+                    navDrawerElement.classList.add('darkDrawer');
+                    navDrawerElement.classList.remove('adminDrawer');
+                }
+            });
         }
     }
 
     function refreshLibraryDrawer(user) {
 
-        var promise = user ? Promise.resolve(user) : ConnectionManager.user(window.ApiClient);
+        if (!enableLibraryNavDrawer) {
+            return;
+        }
 
-        promise.then(function (user) {
-            refreshLibraryInfoInDrawer(user);
+        loadNavDrawer().then(function () {
+            var promise = user ? Promise.resolve(user) : ConnectionManager.user(window.ApiClient);
 
-            document.dispatchEvent(new CustomEvent("libraryMenuCreated", {}));
-            updateLibraryMenu(user.localUser);
+            promise.then(function (user) {
+                refreshLibraryInfoInDrawer(user);
+
+                updateLibraryMenu(user.localUser);
+            });
         });
     }
 
@@ -1025,8 +1003,25 @@
         };
     }
 
-    navDrawerInstance = new navdrawer(getNavDrawerOptions());
-    navDrawerElement.classList.remove('hide');
+    function loadNavDrawer() {
+
+        if (navDrawerInstance) {
+            return Promise.resolve(navDrawerInstance);
+        }
+
+        return new Promise(function (resolve, reject) {
+
+            navDrawerElement = document.querySelector('.mainDrawer');
+            navDrawerScrollContainer = navDrawerElement.querySelector('.scrollContainer');
+
+            require(['navdrawer'], function (navdrawer) {
+                navDrawerInstance = new navdrawer(getNavDrawerOptions());
+                navDrawerElement.classList.remove('hide');
+                resolve(navDrawerInstance);
+            });
+        });
+    }
+
     renderHeader();
 
     Events.on(ConnectionManager, 'apiclientcreated', function (e, apiClient) {
@@ -1046,12 +1041,11 @@
 
     setDrawerClass();
 
-    //require(['appfooter'], function (appfooter) {
-    //    var footer = new appfooter({});
-    //    require(['dockedtabs'], function (dockedtabs) {
-    //        new dockedtabs({
-    //            appFooter: footer
-    //        });
-    //    });
-    //});
+    if (enableBottomTabs) {
+        require(['appfooter-shared', 'dockedtabs'], function (footer, dockedtabs) {
+            new dockedtabs({
+                appFooter: footer
+            });
+        });
+    }
 });
\ No newline at end of file
